@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# (c) Copyright 2020-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2020-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,30 +15,30 @@
 # limitations under the License.
 
 import unittest
-import requests_mock
 
 import opsramp.binding
+import requests_mock
 
 
 class ApiTest(unittest.TestCase):
     def setUp(self):
-        fake_url = 'mock://api.example.com'
-        fake_token = 'unit-test-fake-token'
+        fake_url = "mock://api.example.com"
+        fake_token = "unit-test-fake-token"
         self.ormp = opsramp.binding.Opsramp(fake_url, fake_token)
 
-        self.fake_client_id = 'client_for_unit_test'
+        self.fake_client_id = "client_for_unit_test"
         self.client = self.ormp.tenant(self.fake_client_id)
         assert self.client.is_client()
 
         self.service_maps = self.client.service_maps()
-        assert 'serviceGroups' in str(self.service_maps)
+        assert "serviceGroups" in str(self.service_maps)
 
     def test_service_maps_get_root(self):
         group = self.service_maps
         thisid = 111111
-        expected = {'id': thisid}
+        expected = {"id": thisid}
         with requests_mock.Mocker() as m:
-            url = group.api.compute_url('search')
+            url = group.api.compute_url("search")
             m.get(url, json=expected, complete_qs=True)
             actual = group.get()
             assert actual == expected
@@ -46,10 +46,10 @@ class ApiTest(unittest.TestCase):
     def test_service_maps_get_child(self):
         group = self.service_maps
         thisid = 222222
-        expected = {'id': thisid}
-        sgid = 'some-sgid'
+        expected = {"id": thisid}
+        sgid = "some-sgid"
         with requests_mock.Mocker() as m:
-            url = group.api.compute_url('%s/childs/search' % sgid)
+            url = group.api.compute_url("%s/childs/search" % sgid)
             m.get(url, json=expected, complete_qs=True)
             # test uuid parameter specifically.
             actual = group.get(uuid=sgid)
@@ -61,9 +61,9 @@ class ApiTest(unittest.TestCase):
     def test_service_maps_get_minimal(self):
         group = self.service_maps
         thisid = 333333
-        expected = {'id': thisid}
+        expected = {"id": thisid}
         with requests_mock.Mocker() as m:
-            url = group.api.compute_url('minimal')
+            url = group.api.compute_url("minimal")
             m.get(url, json=expected, complete_qs=True)
             actual = group.get(minimal=True)
             assert actual == expected
@@ -71,8 +71,8 @@ class ApiTest(unittest.TestCase):
     def test_service_maps_create(self):
         group = self.service_maps
         thisid = 444444
-        expected = {'id': thisid}
-        fake_defn = {'name': 'fr dick byrne'}
+        expected = {"id": thisid}
+        fake_defn = {"name": "fr dick byrne"}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url()
             m.post(url, json=expected, complete_qs=True)
@@ -82,8 +82,8 @@ class ApiTest(unittest.TestCase):
     def test_service_maps_update(self):
         group = self.service_maps
         thisid = 123456
-        expected = {'id': thisid}
-        fake_defn = {'name': 'fr todd unctious'}
+        expected = {"id": thisid}
+        fake_defn = {"name": "fr todd unctious"}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url(thisid)
             m.post(url, json=expected, complete_qs=True)
@@ -93,7 +93,7 @@ class ApiTest(unittest.TestCase):
     def test_service_maps_delete(self):
         group = self.service_maps
         thisid = 789012
-        expected = {'id': thisid}
+        expected = {"id": thisid}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url(thisid)
             m.delete(url, json=expected, complete_qs=True)
